@@ -109,7 +109,7 @@
 RobbinsMonro <- function(f, p, ...,
                          Polyak_Juditsky = FALSE,
                          maxiter = 500L, miniter = 100L, k = 3L,
-                         tol = .00001, verbose = TRUE,
+                         tol = .00001, verbose = interactive(),
                          fn.a = function(iter, a = 1, b = 1/2, c = 0, ...)
                              a / (iter + c)^b)
 {
